@@ -19,8 +19,6 @@ from cryptography.hazmat.primitives import hashes, serialization
 from cryptography.hazmat.primitives.asymmetric import ec
 from cryptography.hazmat.primitives.asymmetric.utils import Prehashed
 
-from aws_encryption_sdk.internal.utils import verify_ec_interface
-
 from ...exceptions import NotSupportedError
 from .elliptic_curve import (
     _ecc_encode_compressed_point,
@@ -48,7 +46,7 @@ class _PrehashingAuthenticator(object):
 
     def _set_signature_type(self):
         """Ensures that the algorithm signature type is a known type and sets a reference value."""
-        if not verify_ec_interface(self.algorithm):
+        if not isinstance(self.algorithm.signing_algorithm_info, type(ec.EllipticCurve)):
             raise NotSupportedError("Unsupported signing algorithm info")
         return ec.EllipticCurve
 
