@@ -15,7 +15,6 @@ import sys
 
 import pytest
 from cryptography.hazmat.primitives.asymmetric import ec
-from cryptography.utils import InterfaceNotImplemented
 from mock import MagicMock, sentinel
 from pytest_mock import mocker  # noqa pylint: disable=unused-import
 
@@ -374,22 +373,20 @@ def test_ecc_public_numbers_from_compressed_point(patch_ec, patch_ecc_decode_com
     assert test == sentinel.public_numbers_instance
 
 
-def test_generate_ecc_signing_key_supported(patch_default_backend, patch_ec, patch_verify_interface):
+def test_generate_ecc_signing_key_supported(patch_default_backend, patch_ec):
     patch_ec.generate_private_key.return_value = sentinel.raw_signing_key
-    mock_algorithm_info = MagicMock(return_value=sentinel.algorithm_info)
+    mock_algorithm_info = MagicMock(return_value=sentinel.algorithm_info, spec=patch_ec.EllipticCurve)
     mock_algorithm = MagicMock(signing_algorithm_info=mock_algorithm_info)
 
     test_signing_key = generate_ecc_signing_key(algorithm=mock_algorithm)
 
-    patch_verify_interface.assert_called_once_with(patch_ec.EllipticCurve, mock_algorithm_info)
     patch_ec.generate_private_key.assert_called_once_with(
         curve=sentinel.algorithm_info, backend=patch_default_backend.return_value
     )
     assert test_signing_key is sentinel.raw_signing_key
 
 
-def test_generate_ecc_signing_key_unsupported(patch_default_backend, patch_ec, patch_verify_interface):
-    patch_verify_interface.side_effect = InterfaceNotImplemented
+def test_generate_ecc_signing_key_unsupported(patch_default_backend, patch_ec):
     mock_algorithm_info = MagicMock(return_value=sentinel.algorithm_info)
     mock_algorithm = MagicMock(signing_algorithm_info=mock_algorithm_info)
 
